from .. import Provider as InternetProvider


class Provider(InternetProvider):
    safe_email_tlds = ("com", "net", "ar")
    tlds = ("com", "com.ar", "com.ar", "net", "org", "net.ar", "ar", "ar")
    replacements = (
        ("à", "a"),
        ("â", "a"),
        ("ã", "a"),
        ("á", "a"),
        ("ç", "c"),
        ("é", "e"),
        ("ê", "e"),
        ("í", "i"),
        ("ô", "o"),
        ("ö", "o"),
        ("õ", "o"),
        ("ó", "o"),
        ("ú", "u"),
    )



from .. import Provider as AutomotiveProvider


class Provider(AutomotiveProvider):
    """Implement automotive provider for ``sq_AL`` locale.

    Source:

    - https://en.wikipedia.org/wiki/Vehicle_registration_plates_of_Albania
    """

    license_formats = ("?? ###??",)
